# magna

[![PyPI](https://img.shields.io/pypi/v/magna.svg)](https://pypi.python.org/pypi/magna)

Magna is a collection of bioinformatic datasets and utilities I use in my everyday life.

This has been written with the intention of personal use, but feel free to use/contribute.

**Documentation:** [https://aaronmussig.github.io/magna/](https://aaronmussig.github.io/magna/)


## Contributing

This project uses [Semantic Versioning](http://semver.org/) and [Conventional Commits](https://conventionalcommits.org/)
to automatically generate release notes using [Semantic Release](https://semantic-release.gitbook.io/semantic-release/).

Please ensure that your commits are property formatted.
